@@ -61,3 +61,26 @@ def test_error_raised(md: Markdown, caplog) -> None:
     assert "ValueError" in html
     assert "oh no!" in html
     assert "Execution of python code block exited with non-zero status" in caplog.text
+
+
+def test_can_print_non_string_objects(md: Markdown) -> None:
+    """Assert we can print non-string objects.
+
+    Parameters:
+        md: A Markdown instance (fixture).
+    """
+    html = md.convert(
+        dedent(
+            """
+            ```python exec="yes"
+            class NonString:
+                def __str__(self):
+                    return "string"
+
+            nonstring = NonString()
+            print(nonstring, nonstring)
+            ```
+            """
+        )
+    )
+    assert "Traceback" not in html
